# Changelog
All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/).

## [Unreleased]

## [2020.12.0]

### Changed
- regenerated avpr based on recent traits update

## [2020.08.1]

### Changed
- migrated from smbus to smbus2

## [2020.08.0]

### Changed
- Now uses Avro-RPC [YEP-107](https://yeps.yaq.fyi/107/)
- Uses Flit for distribution

## [2020.05.0]

### Added
- added changelog
- added daemon-level version, see [YEP-105](https://yeps.yaq.fyi/105/)

### Changed
- from now on, yaqd-ti will use date based versioning
- refactored ci

## [0.1.0]

### Added
- initial release

[Unreleased]: https://gitlab.com/yaq/yaqd-ti/-/compare/v2020.12.0...master
[2020.12.0]: https://gitlab.com/yaq/yaqd-ti/-/compare/v2020.08.1...2020.12.0
[2020.08.1]: https://gitlab.com/yaq/yaqd-ti/-/compare/v2020.08.0...2020.08.1
[2020.08.0]: https://gitlab.com/yaq/yaqd-ti/-/compare/v2020.05.0...2020.08.0
[2020.05.0]: https://gitlab.com/yaq/yaqd-ti/-/compare/v0.1.0...v2020.05.0
[0.1.0]: https://gitlab.com/yaq/yaqd-ti/-/tags/v0.1.0
